@@ -3,7 +3,7 @@ package RPerl::Operation::Expression::SubroutineCall;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.003_000;
+our $VERSION = 0.004_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::Operation::Expression);
@@ -28,7 +28,7 @@ sub ast_to_rperl__generate {
 
     if ( ( ref $self ) ne 'Expression_152' ) {
         die RPerl::Parser::rperl_rule__replace(
-            'ERROR ECOGEASRP00, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL: Grammar rule '
+            'ERROR ECOGEASRP000, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL: Grammar rule '
                 . ( ref $self )
                 . ' found where Expression_152 expected, dying' )
             . "\n";
@@ -39,8 +39,22 @@ sub ast_to_rperl__generate {
     my string $left_paren         = $self->{children}->[1];
     my object $arguments_optional = $self->{children}->[2];
     my string $right_paren        = $self->{children}->[3];
-    $rperl_source_group->{PMC}
-        .= $name->{children}->[0] . $left_paren;
+    $rperl_source_group->{PMC} .= $name->{children}->[0] . $left_paren;
+
+    # DEV NOTE, CORRELATION #rp045: identifiers containing underscores may be reserved by C++
+    # NEED ANSWER: how to trigger ECOGEASxP182x? we must first declare a subroutine which will trigger ECOGEASxP181x instead...
+    if (((substr $name, 0, 1) eq '_') and ($modes->{_symbol_table}->{_namespace} eq q{})) {
+        die 'ERROR ECOGEASRP182a, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL:' . "\n" . 'call to global subroutine name ' . q{'} . $name . q{()'} .
+            ' must not start with an underscore, forbidden by C++ specification as a reserved identifier, dying' . "\n";
+    }
+    elsif ($name =~ m/^_[A-Z]/gxms) {
+        die 'ERROR ECOGEASRP182b, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL:' . "\n" . 'call to subroutine name ' . q{'} . $name . q{()'} .
+            ' must not start with an underscore followed by an uppercase letter, forbidden by C++ specification as a reserved identifier, dying' . "\n";
+    }
+    elsif ($name =~ m/__/gxms) {
+        die 'ERROR ECOGEASRP182c, CODE GENERATOR, ABSTRACT SYNTAX TO RPERL:' . "\n" . 'call to subroutine name ' . q{'} . $name . q{()'} .
+            ' must not include a double-underscore, forbidden by C++ specification as a reserved identifier, dying' . "\n";
+    }
 
     if ( exists $arguments_optional->{children}->[0] ) {
         $rperl_source_subgroup = $arguments_optional->{children}->[0]
@@ -76,7 +90,7 @@ sub ast_to_cpp__generate__CPPOPS_CPPTYPES {
 
     if ( ( ref $self ) ne 'Expression_152' ) {
         die RPerl::Parser::rperl_rule__replace(
-            'ERROR ECOGEASCP00, CODE GENERATOR, ABSTRACT SYNTAX TO C++: Grammar rule '
+            'ERROR ECOGEASCP000, CODE GENERATOR, ABSTRACT SYNTAX TO C++: Grammar rule '
                 . ( ref $self )
                 . ' found where Expression_152 expected, dying' )
             . "\n";
@@ -88,6 +102,21 @@ sub ast_to_cpp__generate__CPPOPS_CPPTYPES {
     my object $arguments_optional = $self->{children}->[2];
     my string $right_paren        = $self->{children}->[3];
 
+    # DEV NOTE, CORRELATION #rp045: identifiers containing underscores may be reserved by C++
+    # NEED ANSWER: how to trigger ECOGEASxP182x? we must first declare a subroutine which will trigger ECOGEASxP181x instead...
+    if (((substr $name, 0, 1) eq '_') and ($modes->{_symbol_table}->{_namespace} eq q{})) {
+        die 'ERROR ECOGEASCP182a, CODE GENERATOR, ABSTRACT SYNTAX TO C++:' . "\n" . 'call to global subroutine name ' . q{'} . $name . q{()'} .
+            ' must not start with an underscore, forbidden by C++ specification as a reserved identifier, dying' . "\n";
+    }
+    elsif ($name =~ m/^_[A-Z]/gxms) {
+        die 'ERROR ECOGEASCP182b, CODE GENERATOR, ABSTRACT SYNTAX TO C++:' . "\n" . 'call to subroutine name ' . q{'} . $name . q{()'} .
+            ' must not start with an underscore followed by an uppercase letter, forbidden by C++ specification as a reserved identifier, dying' . "\n";
+    }
+    elsif ($name =~ m/__/gxms) {
+        die 'ERROR ECOGEASCP182c, CODE GENERATOR, ABSTRACT SYNTAX TO C++:' . "\n" . 'call to subroutine name ' . q{'} . $name . q{()'} .
+            ' must not include a double-underscore, forbidden by C++ specification as a reserved identifier, dying' . "\n";
+    }
+
     # remove leading double-colon scope operator '::'
     my string $name_string = $name->{children}->[0];
     if ((substr $name_string, 0, 2) eq '::') {
@@ -105,7 +134,7 @@ sub ast_to_cpp__generate__CPPOPS_CPPTYPES {
     # MongoDB support
     if ($name_string eq 'bson_build') {
         if ((not exists $modes->{_enable_mongodb}) or (not defined $modes->{_enable_mongodb}) or (not $modes->{_enable_mongodb})) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP93, CODE GENERATOR, ABSTRACT SYNTAX TO C++: Found subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP093, CODE GENERATOR, ABSTRACT SYNTAX TO C++: Found subroutine call to '
                 . q{'} . $name_string . q{()'}
                 . ' but MongoDB support is not enabled, perhaps you forgot to load MongoDB support via `use RPerl::Support::MongoDB;`, dying' )
                 . "\n";
@@ -117,80 +146,80 @@ sub ast_to_cpp__generate__CPPOPS_CPPTYPES {
         if ((exists $modes->{_bson_build_inside}) and
             (defined $modes->{_bson_build_inside}) and
             $modes->{_bson_build_inside}) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP94, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP094, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', already inside the same subroutine call, nesting disallowed for this subroutine, dying' ) . "\n";
         }
 
         elsif ((not defined $arguments_optional) or 
             ((ref $arguments_optional) ne '_OPTIONAL')) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP95a, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP095a, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', invalid or no arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
         elsif ((not exists $arguments_optional->{children}) or 
             (not defined $arguments_optional->{children}) or
             (scalar @{$arguments_optional->{children}}) != 1) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP96a, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP096a, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', wrong number of arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
 
         elsif ((not defined $arguments_optional->{children}->[0]) or
-            ((ref $arguments_optional->{children}->[0]) ne 'ListElements_210')) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP95b, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            ((ref $arguments_optional->{children}->[0]) ne 'ListElements_211')) {
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP095b, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', invalid or no arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
         elsif ((not exists $arguments_optional->{children}->[0]->{children}) or
             (not defined $arguments_optional->{children}->[0]->{children}) or
             ((scalar @{$arguments_optional->{children}->[0]->{children}}) != 2)) {  # the empty _STAR_LIST makes 2 elements instead of 1
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP96b, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP096b, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', wrong number of arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
 
         elsif ((not defined $arguments_optional->{children}->[0]->{children}->[1]) or
             ((ref $arguments_optional->{children}->[0]->{children}->[1]) ne '_STAR_LIST')) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP95c, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP095c, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', invalid or no arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
         elsif ((not exists $arguments_optional->{children}->[0]->{children}->[1]->{children}) or
             (not defined $arguments_optional->{children}->[0]->{children}->[1]->{children}) or
             ((scalar @{$arguments_optional->{children}->[0]->{children}->[1]->{children}}) != 0)) {  # the empty _STAR_LST has 0 children elements
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP96c, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP096c, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', wrong number of arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
 
         elsif ((not defined $arguments_optional->{children}->[0]->{children}->[0]) or
-            ((ref $arguments_optional->{children}->[0]->{children}->[0]) ne 'ListElement_211')) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP95d, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            ((ref $arguments_optional->{children}->[0]->{children}->[0]) ne 'ListElement_212')) {
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP095d, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', invalid or no arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
         elsif ((not exists $arguments_optional->{children}->[0]->{children}->[0]->{children}) or
             (not defined $arguments_optional->{children}->[0]->{children}->[0]->{children}) or
             ((scalar @{$arguments_optional->{children}->[0]->{children}->[0]->{children}}) != 1)) {
 #            RPerl::diag( 'in SubroutineCall->ast_to_cpp__generate__CPPOPS_CPPTYPES(), call to bson_build(), have $arguments_optional->{children}->[0]->{children}->[0]->{children} = ' . "\n" . RPerl::Parser::rperl_ast__dump($arguments_optional->{children}->[0]->{children}->[0]->{children}) . "\n" );
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP96d, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP096d, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', wrong number of arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
 
         elsif ((not defined $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]) or
             ((ref $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]) ne 'SubExpression_161')) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP95e, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP095e, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', invalid or no arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
         elsif ((not exists $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}) or
             (not defined $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}) or
             ((scalar @{$arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}}) != 1)) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP96e, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP096e, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', wrong number of arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
 
         elsif ((not defined $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]) or
-            ((ref $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]) ne 'HashReference_231')) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP95f, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            ((ref $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]) ne 'HashReference_232')) {
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP095f, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', invalid or no arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
         elsif ((not exists $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]->{children}) or
             (not defined $arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]->{children}) or
             ((scalar @{$arguments_optional->{children}->[0]->{children}->[0]->{children}->[0]->{children}->[0]->{children}}) == 0)) {
-            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP96f, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
+            die RPerl::Parser::rperl_rule__replace( 'ERROR ECOGEASCP096f, CODE GENERATOR, ABSTRACT SYNTAX TO C++: In subroutine call to '
                 . q{'} . $name_string . q{()'} . ', wrong number of arguments found, must be exactly 1 non-empty hashref, dying' ) . "\n";
         }
 
