@@ -16,7 +16,5 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-our integer $foo = sub {
-    return 23;
-};
+sub foo { { my integer $RETURN_TYPE }; return 23; }
 foo()
