@@ -9,8 +9,6 @@ use strict;
 use warnings;
 our $VERSION = 0.001_000;
 
-our number $empty_sub = sub {
-    return -2333_456_789.234_56;
-};
+sub empty_sub { { my number $RETURN_TYPE }; return -2333_456_789.234_56; }
 
 1;    # end of package
