@@ -1,5 +1,5 @@
 # [[[ PREPROCESSOR ]]]
-# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'ERROR ECOPARP00' >>>
 # <<< PARSE_ERROR: 'Unexpected Token:  +' >>>
 
 # [[[ HEADER ]]]
@@ -13,8 +13,6 @@ our $VERSION = 0.001_000;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our number $empty_sub = sub {
-    return +.234_567_89;
-};
+sub empty_sub { { my number $RETURN_TYPE }; return +.234_567_89; }
 
 1;    # end of package
