@@ -9,8 +9,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our string $empty_sub = sub {
-    return "\n\t`~!#%\t\.\t^&*()-_=+[]{}\n|;:'\t,<.\n>/?\t.";
-};
+sub empty_sub { { my string $RETURN_TYPE }; return "\n\t`~!#%\t\.\t^&*()-_=+[]{}\n|;:'\t,<.\n>/?\t."; }
 
 1;    # end of package
