@@ -18,13 +18,14 @@ our hashref $properties
     = { empty_property => my integer $TYPED_empty_property = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-our void::method $empty_method = sub {
+sub empty_method {
+    { my void::method $RETURN_TYPE };
     (   my object $sel,
         my number $foo,
         my number_arrayref $bar,
         my number_hashref $baz
     ) = @ARG;
     return 2;
-};
+}
 
 1;    # end of class
