@@ -17,9 +17,7 @@ our hashref $properties
     = { empty_property => my integer $TYPED_empty_property = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-our void::method $empty_method = sub {
-    return 2;
-};
+sub empty_method { { my void::method $RETURN_TYPE }; return 2; }
 
 1;    # end of class
 
@@ -42,9 +40,7 @@ our hashref $properties
     = { empty_property_additional => my integer $TYPED_empty_property_additional = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-our void::method $empty_method_additional = sub {
-    return 2;
-};
+sub empty_method_additional { { my void::method $RETURN_TYPE }; return 2; }
 
 1;    # end of class
 
