@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< PARSE_ERROR: 'ERROR ECVPAPC02' >>>
+# <<< PARSE_ERROR: 'ERROR ECOPAPC02' >>>
 # <<< PARSE_ERROR: 'Perl::Critic::Policy::CodeLayout::ProhibitParensWithBuiltins' >>>
 
 # [[[ HEADER ]]]
@@ -17,4 +17,5 @@ our $VERSION = 0.001_000;
 # [[[ OPERATIONS ]]]
 
 # DEV NOTE: DO NOT RUN PERLTIDY ON THIS FILE!  the line below should read 'die(...' not 'die (...'
-die( ( @{ [2] }, "\n" ) );
\ No newline at end of file
+die( @{ [2] }, "\n" );
+
