@@ -15,9 +15,8 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-our integer $foo = sub {
-    return - 1;
-};
+sub foo { { my integer $RETURN_TYPE }; return - 1; }
 
 # [[[ OPERATIONS ]]]
-foo();
\ No newline at end of file
+foo();
+
