@@ -10,9 +10,10 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub {
+sub empty_sub {
+    { my void $RETURN_TYPE };
     ( my number $foo, my string $bar, my scalartype_arrayref $baz, my integer_hashref $bat ) = @;
     return 1;
-};
+}
 
 1;    # end of package
